#[repr(u8)]pub enum Trigburst {
SINGLE = 0,
BURST = 1,
}Variants
SINGLE = 0
Single transfer. Hardware trigger causes a single transfer.
BURST = 1
Burst transfer. When the trigger for this channel is set to edge triggered, a hardware trigger causes a burst transfer, as defined by BURSTPOWER. When the trigger for this channel is set to level triggered, a hardware trigger causes transfers to continue as long as the trigger is asserted, unless the transfer is complete.
Implementations