#[repr(u8)]pub enum Trigtype {
EDGE = 0,
LEVEL = 1,
}Variants
EDGE = 0
Edge. Hardware trigger is edge triggered. Transfers will be initiated and completed, as specified for a single trigger.
LEVEL = 1
Level. Hardware trigger is level triggered. Note that when level triggering without burst (BURSTPOWER = 0) is selected, only hardware triggers should be used on that channel. Transfers continue as long as the trigger level is asserted. Once the trigger is de-asserted, the transfer will be paused until the trigger is, again, asserted. However, the transfer will not be paused until any remaining transfers within the current BURSTPOWER length are completed.
Implementations